@@ -494,13 +494,13 @@ void AudioVideoActor::stop () {
 
 void AudioVideoActor::pause () {
     Process *process = m_agent->control ()->process ();
-    if (process && process->state () == Process::Playing)
+    if (process && process->playing ())
         process->pause ();
 }
 
 void AudioVideoActor::unpause () {
     Process *process = m_agent->control ()->process ();
-    if (process && process->state () == Process::Paused)
+    if (process && process->playing ())
         process->pause ();
 }
 
