@@ -339,10 +339,7 @@ gboolean locationbarKeyEvent (GtkWidget *w, GdkEventKey *e, Application *app) {
 static void windowTopMost (GObject * self, GParamSpec *gps, Application * app) {
     (void)gps;
     app->top_most_window = hildon_window_get_is_topmost (HILDON_WINDOW (app->window));
-    if (app->fullscreen && app->top_most_window)
-        app_normal_screen (app);
-    else
-        app_update_screen_blanking (app);
+    app_update_screen_blanking (app);
 }
 
 static void infoAreaRealized (GtkWidget *widget, gpointer p)
