@@ -30,6 +30,7 @@
 #include "kmplayer.h"
 #include "kmplayercontrol.h"
 #include "actor.h"
+#include "expression.h"
 
 using namespace KMPlayer;
 
@@ -165,6 +166,96 @@ void *Group::role (KMPlayer::RoleType msg, void *content)
 }
 
 // gconftool -s -t string /apps/maemo/kmplayer/playlist_file /home/koos/playlist.xml
+
+static void deleteAuxiliaries (Node *p)
+{
+    for (Node *c = p->firstChild (); c;) {
+        Node *n = c->nextSibling ();
+        if (c->auxiliaryNode ())
+            p->removeChild (c);
+        //else
+        //    deleteAuxiliaries (c);
+        c = n;
+    }
+}
+void Playlist::show (View *view)
+{
+    if (!view->show)
+        view->show = evaluateExpr (view->getAttribute ("show"));
+    if (!open)
+        deleteAuxiliaries (this);
+    if (view->show) {
+        Node *before = NULL;
+        if (!view->before)
+            view->before = evaluateExpr (view->getAttribute ("before"));
+        if (view->before) {
+            view->before->setRoot (this);
+            NodeValueList *ls = view->before->toNodeList ();
+            if (ls->first())
+                before = ls->first()->data.node;
+        }
+        if (!view->before)
+            before = meta->nextSibling ();
+
+        GHashTable *groups = NULL;
+        String groupBy = view->getAttribute ("groupBy");
+        TrieString attr_groupBy (groupBy);
+        if (!groupBy.isEmpty ())
+            groups = g_hash_table_new (g_str_hash, g_str_equal);
+
+        view->show->setRoot (this);
+        NodeValueList *lst = view->show->toNodeList ();
+        for (NodeValueItem *itm = lst->first(); itm; itm = itm->nextSibling())
+            if (itm->data.node->isElementNode ()) {
+                Element *e = static_cast <Element *> (itm->data.node);
+
+                PlaylistItem *itm = new PlaylistItem (m_doc, app, false);
+                NodePtr guard = itm;
+                itm->setAttribute (StringPool::attr_url,
+                        e->getAttribute (StringPool::attr_url));
+                itm->setAttribute (StringPool::attr_title,
+                        e->getAttribute (StringPool::attr_title));
+                itm->setAuxiliaryNode (true);
+                itm->closed ();
+
+                groupBy = e->getAttribute (attr_groupBy).stripWhiteSpace ();
+                if (groups && !groupBy.isEmpty ()) {
+                    Node *group = (Node *)g_hash_table_lookup (groups, (const char *)groupBy);
+                    if (!group) {
+                        PlaylistGroup *g = new PlaylistGroup(m_doc, app, false);
+                        insertBefore (g, before);
+                        g->setAttribute (StringPool::attr_title, groupBy);
+                        g->setAuxiliaryNode (true);
+                        g->closed ();
+                        group = g;
+                        g_hash_table_insert (groups,
+                                (void *) (const char *) groupBy, (Node *) g);
+                    }
+                    group->appendChild (itm);
+                } else {
+                    insertBefore (itm, before);
+                }
+            }
+        if (groups)
+            g_hash_table_destroy (groups);
+        delete lst;
+        debugLog () << "Playlist;;show open " << open << endl;
+        if (!open)
+            SourceDocument::message (MsgListUpdated, NULL);
+    }
+}
+
+void Playlist::closed ()
+{
+    PlaylistMetaGroup *m = static_cast <PlaylistMetaGroup *> (meta.ptr ());
+    if (m) {
+        Views *views = static_cast <Views *> (m->views.ptr ());
+        if (views && views->active_view)
+            show (static_cast <View *> (views->active_view.ptr ()));
+    }
+    FileDocument::closed();
+}
+
 KDE_NO_EXPORT void Playlist::defer () {
     if (playmode)
         KMPlayer::Document::defer ();
@@ -196,6 +287,8 @@ KDE_NO_EXPORT KMPlayer::Node *Playlist::childFromTag (const String & tag) {
         return new PlaylistItem (m_doc, app, playmode);
     else if (!strcmp (name, "group"))
         return new PlaylistGroup (m_doc, app, playmode);
+    else if (!strcmp (name, "meta"))
+        return new PlaylistMetaGroup (m_doc, app);
     else if (!strcmp (name, "object"))
         return new HtmlObject (m_doc, app, playmode);
     return FileDocument::childFromTag (tag);
@@ -273,24 +366,13 @@ KDE_NO_EXPORT void PlaylistItem::begin () {
         Mrl::begin ();
 }
 
-KDE_NO_CDTOR_EXPORT
-PlaylistGroup::PlaylistGroup (NodePtr & doc, Application * a, const String & pn)
- : Element (doc, KMPlayer::id_node_group_node),
-   app (a),
-   playmode (false) {
-    title = pn;
-    if (!pn.isEmpty ())
-        setAttribute (KMPlayer::StringPool::attr_title, pn);
-}
-
-KDE_NO_CDTOR_EXPORT
-PlaylistGroup::PlaylistGroup (NodePtr & doc, Application * a, bool lm)
- : Element (doc, KMPlayer::id_node_group_node),
+PlaylistGroupBase::PlaylistGroupBase (NodePtr & doc, short _id, Application *a, bool lm)
+ : Element (doc, _id),
    app (a),
    playmode (lm) {
 }
 
-KDE_NO_EXPORT KMPlayer::Node *PlaylistGroup::childFromTag (const String & tag) {
+KMPlayer::Node *PlaylistGroupBase::childFromTag (const String & tag) {
     const char * name = (const char *) tag;
     if (!strcmp (name, "item"))
         return new PlaylistItem (m_doc, app, playmode);
@@ -301,19 +383,113 @@ KDE_NO_EXPORT KMPlayer::Node *PlaylistGroup::childFromTag (const String & tag) {
     return NULL;
 }
 
-KDE_NO_EXPORT void PlaylistGroup::closed () {
+KDE_NO_EXPORT void PlaylistGroupBase::closed () {
     if (title.isEmpty ())
         title = getAttribute (KMPlayer::StringPool::attr_title);
     Element::closed ();
 }
 
-void *PlaylistGroup::role (KMPlayer::RoleType msg, void *content)
+void *PlaylistGroupBase::role (KMPlayer::RoleType msg, void *content)
 {
     if (KMPlayer::RolePlaylist == msg)
         return (KMPlayer::PlaylistRole *) this ;
     return Element::role (msg, content);
 }
 
+PlaylistGroup::PlaylistGroup (NodePtr &doc, Application *a, bool lm)
+ : PlaylistGroupBase (doc, KMPlayer::id_node_group_node, a, lm)
+{}
+
+PlaylistMetaGroup::PlaylistMetaGroup (NodePtr &doc, Application *a)
+ : PlaylistGroupBase (doc, KMPlayer::id_node_meta_group, a, false)
+{}
+
+void PlaylistMetaGroup::closed ()
+{
+    for (Node *c = firstChild (); c; c = c->nextSibling ())
+        if (id_node_meta_views == c->id) {
+            views = c;
+            Node *p = parentNode ();
+            if (p && id_node_playlist_document == p->id)
+                static_cast <Playlist *> (p)->meta = this;
+            break;
+        }
+    PlaylistGroupBase::closed ();
+}
+
+Node *PlaylistMetaGroup::childFromTag (const String &tag)
+{
+    if (tag == "views")
+        return new Views (m_doc);
+    return PlaylistGroupBase::childFromTag (tag);
+}
+
+Views::Views (KMPlayer::NodePtr &doc) : Element (doc, id_node_meta_views)
+{}
+
+void Views::closed ()
+{
+    for (Node *c = firstChild (); c; c = c->nextSibling ())
+        if (id_node_meta_view == c->id) {
+            active_view = c;
+            break;
+        }
+    Element::closed ();
+}
+
+KMPlayer::Node *Views::childFromTag (const String &tag)
+{
+    if (tag == "view")
+        return new View (m_doc);
+    return NULL;
+}
+
+void Views::message (MessageType msg, void *content)
+{
+    switch (msg) {
+
+    case MsgChildFinished: {
+        Posting *post = (Posting *) content;
+        if (post->source && id_node_meta_view == post->source->id)
+            active_view = post->source;
+        state = state_deactivated;
+        break; // not forwarding to Element, preventing playlist traversal
+    }
+    default:
+        Element::message (msg, content);
+    }
+}
+
+View::View (NodePtr &doc)
+ : Mrl (doc, id_node_meta_view), show (NULL), before (NULL)
+{}
+
+View::~View ()
+{
+    delete show;
+    delete before;
+}
+
+void View::closed ()
+{
+    title = getAttribute (KMPlayer::StringPool::attr_title);
+    groupBy = getAttribute ("groupBy");
+    if (title.isEmpty ()) {
+        title = groupBy;
+        if (title.isEmpty ())
+            title = String ("View ") + getAttribute ("show");
+    }
+    Element::closed ();
+}
+
+void View::activate ()
+{
+    debugLog () << "View::activate " << m_doc->id << endl;
+    if (m_doc->id == id_node_playlist_document)
+        static_cast <Playlist *> (m_doc.ptr ())->show (this);
+    finish ();
+}
+
 KDE_NO_CDTOR_EXPORT
 HtmlObject::HtmlObject (KMPlayer::NodePtr &doc, Application *a, bool pm)
   : PlaylistItemBase (doc, KMPlayer::id_node_html_object, a, pm) {}
