@@ -87,6 +87,14 @@ void SourceDocument::message (MessageType msg, void *data) {
             }
         return;
 
+    case MsgListUpdated:
+        for (PlayListData *pd = m_control->playlist_data; pd; pd = pd->next)
+            if (pd->document.ptr () == this) {
+                updateTree (m_control->m_app, pd->id);
+                break;
+            }
+        return;
+
     default:
         break;
     }
@@ -235,7 +243,7 @@ void Control::init () {
         GConfValue *value = gconf_entry_get_value (entry);
         const char *str = gconf_value_get_string (value);
         if (str && *str) {
-            Playlist *expl = new Playlist (m_app, 0L);
+            Playlist *expl = new Playlist (m_app, this);
             extra_playlists.append (expl);
             expl->title = entry->key + strlen (GCONF_KEY_LISTS) + 1;
             expl->path = str;
@@ -1003,7 +1011,7 @@ static Mrl *findFirstPlayable (Node *n) {
 
 void KMPlayer::jump (Node *n, Control *ctr) {
     Mrl *mrl = n->document() != ctr->playlist_data->document
-        ? isListItem (n->id) ? n->mrl () : NULL
+        ? isListItem (n->id) || id_node_meta_view == n->id ? n->mrl () : NULL
         : findFirstPlayable (n);
     if (mrl && mrl->view_mode == Mrl::SingleMode) {
         if (n->document() == ctr->playlist_data->document && !mrl->isPlayable())
