@@ -1715,7 +1715,7 @@ void KMPlayer::readXML (NodePtr root, TextStream & in, const String & firstline,
     }
     if (!in.atEnd ())
         parser.parse (in);
-    for (NodePtr e = root; e; e = e->parentNode ()) {
+    for (NodePtr e = root->parentNode (); e; e = e->parentNode ()) {
         if (e->open)
             break;
         e->closed ();
