@@ -16,8 +16,7 @@
 using namespace KMPlayer;
 
 static GdkPixbuf *folder_pix;
-static GdkPixbuf *auxiliary_pix;
-static GdkPixbuf *auxiliary_fld_pix;
+static GdkPixbuf *view_pix;
 static GdkPixbuf *unknown_pix;
 static GdkPixbuf *config_pix;
 static GdkPixbuf *music_pix;
@@ -82,8 +81,8 @@ enum {
 };
 
 static GdkPixbuf *iconForNode (Node *n, int child_count) {
-    if (n->auxiliaryNode ())
-        return child_count > 0 ? auxiliary_fld_pix : auxiliary_pix;
+    if (id_node_meta_view == n->id)
+        return view_pix;
     return n->isPlayable()
         ? n->mrl ()->resolved
             ? n->mrl ()->audio_only
@@ -763,14 +762,12 @@ GtkWidget * createTreeView (Application * app) {
     GtkIconTheme *icon_theme = gtk_icon_theme_get_default();
     folder_pix = gtk_icon_theme_load_icon (icon_theme,
             "filemanager_video_folder", 26, (GtkIconLookupFlags)0, 0L);
-    auxiliary_pix = gtk_icon_theme_load_icon (icon_theme,
-            "general_profile", 26, (GtkIconLookupFlags)0, 0L);
-    auxiliary_fld_pix = gtk_icon_theme_load_icon (icon_theme,
-            "filemanager_document_folder", 26, (GtkIconLookupFlags)0, 0L);
     unknown_pix = gtk_icon_theme_load_icon (icon_theme,
             "filemanager_nonreadable_file", 26, (GtkIconLookupFlags)0, 0L);
     config_pix = gtk_icon_theme_load_icon (icon_theme,
             "general_settings", 26, (GtkIconLookupFlags)0, 0L);
+    view_pix = gtk_icon_theme_load_icon (icon_theme,
+            "qgn_widg_mplayer_play", 26, (GtkIconLookupFlags)0, 0L);
     music_pix = gtk_icon_theme_load_icon (icon_theme,
             "general_audio_file", 26, (GtkIconLookupFlags)0, 0L);
     video_pix = gtk_icon_theme_load_icon (icon_theme,
