@@ -193,7 +193,7 @@ public:
     void writeEvent (UnixProcess *);
     void readEvent (UnixProcess *);
 
-private:
+protected:
     bool sendCommand (const String &);
     typedef std::list <String> StringList;
     StringList commands;
@@ -212,69 +212,13 @@ private:
 
 #ifdef __ARMEL__
 
-class NpStream;
-
-class KMPLAYER_NO_EXPORT NpPlayer : public Process {
+class KMPLAYER_NO_EXPORT NpPlayer : public MPlayer {
 public:
     NpPlayer (ProcessNotify * ctrl);
-    ~NpPlayer ();
 
-    virtual bool ready (unsigned int);
     virtual bool play (NodePtr mrl);
-    virtual bool stop ();
-    virtual bool quit ();
-    virtual void setVideoWindow (int x, int y, int w, int h);
-    //virtual String menuName () const;
-
-    void pluginEmbedded ();
-    void requestStream (void *inst, uint32_t id, const String & url,
-            const String & target, unsigned plen, const char *post);
-    void destroyStream (void *inst, uint32_t id);
-
-    void streamFinished (NpStream *ns);
-    void processStreams ();
-    String evaluateScript (const String &script);
 
     static bool isFlashMimeType (const String &mime);
-
-    GTree *streams;
-private:
-    GTree *plugins;
-    char *mime;
-    void *npdata;
-    int streams_deleted;
-    int argc;
-    char **argn;
-    char **argv;
-    bool processing;
-};
-
-class KMPLAYER_NO_EXPORT NpStream : public IOJobListener {
-public:
-    enum Reason {
-        NoReason = -1,
-        BecauseDone = 0, BecauseError = 1, BecauseStopped = 2
-    };
-
-    NpStream (NpPlayer *player, uint32_t stream, const URL & url,
-            unsigned post_len, const char *post);
-    ~NpStream ();
-
-    void open ();
-    void close ();
-
-    virtual void jobData (IOJob * job, ByteArray & data);
-    virtual void jobResult (IOJob * job);
-    virtual void redirected (IOJob * job, const String & uri);
-
-    uint32_t stream;
-    URL url;
-    IOJob *job;
-    uint32_t bytes;
-    ByteArray post_data;
-    Reason finish_reason;
-private:
-    NpPlayer *player;
 };
 
 #endif //__ARMEL__
