@@ -208,8 +208,8 @@ extern "C" {
 
 static void npSetDimension (void *ndata, int w, int h)
 {
-    output ("ID_VIDEO_WIDTH=%d\n", w);
-    output ("ID_VIDEO_HEIGHT=%d\n", h);
+    //output ("ID_VIDEO_WIDTH=%d\n", w);
+    //output ("ID_VIDEO_HEIGHT=%d\n", h);
 }
 
 static void npGetUrl (void *inst, uint32_t stream,
@@ -327,7 +327,8 @@ static gboolean initPlayer (void * p)
         g_tree_insert (npp_plugins, (char *) mimetype, nplib);
     }
     nppInstanceWindowParent (npdata, (void *) socket_id);
-    nppInstanceWindowDimension (npdata, 0, 0, 800, parent_id ? 480 : 424);
+    nppInstanceWindowDimension (npdata,
+            0, 0, parent_id ? 640 : 565, parent_id ? 480 : 424);
 
     if (!play ())
         quit ();
@@ -465,7 +466,7 @@ static void pluginAdded (GtkSocket *socket, gpointer p)
 static gboolean configureEvent(GtkWidget *w, GdkEventConfigure *e, gpointer d)
 {
     (void)w; (void)d;
-    nppInstanceWindowDimension (npdata, e->x, e->y, e->width, e->height);
+    //nppInstanceWindowDimension (npdata, e->x, e->y, e->width, e->height);
 }
 
 static void windowCreatedEvent (GtkWidget *w, gpointer d) {
@@ -502,8 +503,12 @@ static void windowDestroyEvent (GtkWidget *w, gpointer d)
 }
 
 static gboolean cb_quit (gpointer data) {
+    static gboolean been_here;
     (void)data;
-    quit ();
+    if (!been_here) {
+        been_here = TRUE;
+        quit ();
+    }
     return FALSE;
 }
 
@@ -558,6 +563,7 @@ static void sig_abort(int i) {
 int main (int argc, char **argv) {
     GTree *params;
     GtkWidget *window;
+    GtkWidget *align;
     GdkColormap *color_map;
     GdkColor bg_color;
     GIOChannel *channel_in;
@@ -638,6 +644,8 @@ int main (int argc, char **argv) {
     g_signal_connect (G_OBJECT (window), "configure-event",
             GTK_SIGNAL_FUNC (configureEvent), NULL);
 
+    align = gtk_alignment_new (0, 0, 1, 1);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 0, 80, 80);
     xembed = gtk_socket_new();
     g_signal_connect (G_OBJECT (xembed), "plug-added",
             GTK_SIGNAL_FUNC (pluginAdded), NULL);
@@ -646,7 +654,8 @@ int main (int argc, char **argv) {
     gdk_colormap_query_color (color_map, 0, &bg_color);
     gtk_widget_modify_bg (xembed, GTK_STATE_NORMAL, &bg_color);
 
-    gtk_container_add (GTK_CONTAINER (window), xembed);
+    gtk_container_add (GTK_CONTAINER (window), align);
+    gtk_container_add (GTK_CONTAINER (align), xembed);
 
     if (!parent_id) {
         gtk_widget_set_size_request (window, 800, parent_id ? 480 : 424);
